# Copyright ⓒ 2016 Red Hat, Inc.
# This file is part of fegistry.
#
# fegistry is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# fegistry is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with fegistry.  If not, see <http://www.gnu.org/licenses/>.
"""This test suite contains tests on fegistry.views."""

import json
import unittest

import flask

from fegistry import views


class ViewsTestCase(unittest.TestCase):
    """A superclass for testing the views module."""
    def setUp(self):
        views.app.config['TESTING'] = True
        self.app = views.app.test_client()


class TestAddDockerHeaders(unittest.TestCase):
    """This test class contains tests on the add_docker_headers() function."""
    def test_add_docker_headers(self):
        """Assert correct behavior when the status code is 200."""
        response = flask.Response(status="200")

        response = views.add_docker_headers(response)

        self.assertEqual(response.headers['Docker-Distribution-API-Version'], 'registry/2.0')


class Testv2(ViewsTestCase):
    """This test class tests the v2() function."""
    def test_v2(self):
        """Check the /v2/ handler."""
        response = self.app.get('/v2/')

        self.assertEqual(response.status_code, 200)
        self.assertEqual(json.loads(response.get_data().decode('utf-8')), {})
        self.assertEqual(response.headers['Docker-Distribution-API-Version'], 'registry/2.0')
        self.assertEqual(response.headers['Content-Type'], 'application/json')
